<?php
/**
 * Copyright 2010, 2011 pixeltricks GmbH
 *
 * This file is part of SilvercartPdfInvoice.
 *
 * SilvercartPdfInvoice is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * SilvercartPdfInvoice is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with SilvercartPdfInvoice.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package Silvercart
 * @subpackage PdfInvoice
 */

/**
 * SilvercartPdfInvoice configuration object
 * 
 * @package Silvercart
 * @subpackage PdfInvoice
 * @author Sebastian Diel <sdiel@pixeltricks.de>
 * @copyright 2011 pixeltricks GmbH
 * @since 26.08.2011
 * @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
 */
class SilvercartPdfInvoiceConfig extends DataObject {
    
    public static $db = array(
        'LayoutLogoPosition' => 'Enum("Left,Right","Left")',
        'LayoutSenderAddress' => 'Varchar(255)',
        'LayoutFooter' => 'Enum("1,2","1")',
        'LayoutFooterColumn1' => 'Text',
        'LayoutFooterColumn2' => 'Text',
        'LayoutFooterColumn3' => 'Text',
        'LayoutFooterColumn4' => 'Text',
        'SecurityDeleteAfterSending' => 'Boolean',
        'SecurityProtectedPath' => 'Varchar(255)',
    );
    
    public static $has_one = array(
        'LayoutLogo' => 'Image',
    );
    
    public static $config = null;
    public static $rewriteRuleDir = 'assets/scpdf';

    /**
     * Returns the translated singular name of the object. If no translation exists
     * the class name will be returned.
     * 
     * @return string The objects singular name
     * 
     * @author Sebastian Diel <sdiel@pixeltricks.de>
     * @since 26.08.2011
     */
    public function singular_name() {
        if (_t('SilvercartPdfInvoiceConfig.SINGULARNAME')) {
            return _t('SilvercartPdfInvoiceConfig.SINGULARNAME');
        } else {
            return parent::singular_name();
        } 
    }
    
    /**
     * Returns the translated plural name of the object. If no translation exists
     * the class name will be returned.
     * 
     * @return string the objects plural name
     * 
     * @author Sebastian Diel <sdiel@pixeltricks.de>
     * @since 26.08.2011
     */
    public function plural_name() {
        if (_t('SilvercartPdfInvoiceConfig.PLURALNAME')) {
            return _t('SilvercartPdfInvoiceConfig.PLURALNAME');
        } else {
            return parent::plural_name();
        }   
    }

    /**
     * Summaryfields for display in tables.
     *
     * @return array
     *
     * @author Sebastian Diel <sdiel@pixeltricks.de>
     * @since 26.08.2011
     */
    public function summaryFields() {
        return array_merge(
            parent::summaryFields(),
            array(
                'LayoutLogoPosition'            => _t('SilvercartPdfInvoiceConfig.LAYOUT_LOGO_POSITION', 'Position of your logo'),
                'SecurityDeleteAfterSending'    => _t('SilvercartPdfInvoiceConfig.SECURITY_DELETE_AFTER_SENDING', 'Delete PDF files after sending them via email'),
                'SecurityProtectedPath'         => _t('SilvercartPdfInvoiceConfig.SECURITY_PROTECTED_PATH', 'Absolute path to a secure direcory of the server (outside of the servers HTTP root directory)'),
            )
        );
    }

    /**
     * Field labels for display in tables.
     *
     * @param boolean $includerelations A boolean value to indicate if the labels returned include relation fields
     * 
     * @return array
     *
     * @author Sebastian Diel <sdiel@pixeltricks.de>
     * @since 26.08.2011
     */
    public function fieldLabels($includerelations = true) {
        return array_merge(
            parent::fieldLabels($includerelations),
            array(
                'LayoutLogo'                    => _t('SilvercartPdfInvoiceConfig.LAYOUT_LOGO', 'Your logo to display on the PDF invoice'),
                'LayoutLogoPosition'            => _t('SilvercartPdfInvoiceConfig.LAYOUT_LOGO_POSITION', 'Position of your logo'),
                'LayoutFooter'                  => _t('SilvercartPdfInvoiceConfig.LAYOUT_FOOTER', 'Layout of footer section'),
                'LayoutFooterColumn1'           => _t('SilvercartPdfInvoiceConfig.LAYOUT_FOOTER_COLUMN1', 'Content of column1'),
                'LayoutFooterColumn2'           => _t('SilvercartPdfInvoiceConfig.LAYOUT_FOOTER_COLUMN2', 'Content of column2'),
                'LayoutFooterColumn3'           => _t('SilvercartPdfInvoiceConfig.LAYOUT_FOOTER_COLUMN3', 'Content of column3'),
                'LayoutFooterColumn4'           => _t('SilvercartPdfInvoiceConfig.LAYOUT_FOOTER_COLUMN4', 'Content of column4'),
                'LayoutSenderAddress'           => _t('SilvercartPdfInvoiceConfig.LAYOUT_SENDER_ADDRESS', 'Address of invoice sender (will be displayed as one line above the recipient)'),
                'SecurityDeleteAfterSending'    => _t('SilvercartPdfInvoiceConfig.SECURITY_DELETE_AFTER_SENDING', 'Delete PDF files after sending them via email'),
                'SecurityProtectedPath'         => _t('SilvercartPdfInvoiceConfig.SECURITY_PROTECTED_PATH', 'Absolute path to a secure direcory of the server (outside of the servers HTTP root directory)'),
            )
        );
    }
    
    /**
     * SilvercartPdfInvoiceConfig default records.
     * 
     * @return void
     *
     * @author Sebastian Diel <sdiel@pixeltricks.de>
     * @since 26.08.2011
     */
    public function requireDefaultRecords() {
        parent::requireDefaultRecords();
        $pdfInvoiceConfig = DataObject::get_one('SilvercartPdfInvoiceConfig');
        if (!$pdfInvoiceConfig) {
            $pdfInvoiceConfig = new SilvercartPdfInvoiceConfig();
            $pdfInvoiceConfig->write();
        }
        $invoceNumberRange = DataObject::get_one('SilvercartNumberRange', "`Identifier` = 'InvoiceNumber'");
        if (!$invoceNumberRange) {
            $invoceNumberRange = new SilvercartNumberRange();
            $invoceNumberRange->Title = _t('SilvercartPdfInvoiceConfig.INVOICENUMBER', 'Invoicenumber');
            $invoceNumberRange->StartCount = '100000';
            $invoceNumberRange->EndCount = '999999';
            $invoceNumberRange->ActualCount = '100000';
            $invoceNumberRange->Identifier = 'InvoiceNumber';
            $invoceNumberRange->write();
        }
    }
    
    /**
     * Manipulates the CMS fields
     *
     * @param array $params params
     * 
     * @return FieldSet
     */
    public function getCMSFields($params = null) {
        $fields = parent::getCMSFields($params);
        
        $layoutTab      = $fields->findOrMakeTab('Root.Main');
        $layoutTab->setTitle(_t('SilvercartPdfInvoiceConfig.LAYOUT', 'Layout'));
        $securityTab    = $fields->findOrMakeTab('Root.Security', _t('SilvercartPdfInvoiceConfig.SECURITY', 'Security'));
        
        $fields->dataFieldByName('LayoutFooter')->setSource(array(
            1 => _t('SilvercartPdfInvoiceConfig.LAYOUT_FOOTER_1'),
            2 => _t('SilvercartPdfInvoiceConfig.LAYOUT_FOOTER_2'),
        ));
        
        if ($this->LayoutFooter == 1) {
            $fields->removeByName('LayoutFooterColumn4');
        }
        
        $fields->addFieldToTab('Root.Security', $fields->dataFieldByName('SecurityDeleteAfterSending'));
        $fields->addFieldToTab('Root.Security', $fields->dataFieldByName('SecurityProtectedPath'));
        
        return $fields;
    }
    
    /**
     * The PDF invoice config can't be deleted. This method will always return 
     * false
     *
     * @param Member $member Member
     * 
     * @return bool
     *
     * @author Sebastian Diel <sdiel@pixeltricks.de>
     * @since 26.08.2011
     */
    public function canDelete($member = null) {
        return false;
    }

    /**
     * Returns the SilvercartPdfInvoiceConfig or triggers an error if not existent.
     *
     * @return SilvercartPdfInvoiceConfig
     */
    public static function getConfig() {
        if (is_null(self::$config)) {
            self::$config = DataObject::get_one('SilvercartPdfInvoiceConfig');
        }
        return self::$config;
    }
    
    /**
     * Returns the base path of the PDF
     *
     * @return string 
     */
    public function getBasePath() {
        if (empty ($this->SecurityProtectedPath)) {
            $basePath   = Director::baseFolder() . '/silvercart_order_pdfinvoice/files/';
        } else {
            $basePath = $this->SecurityProtectedPath;
            $htapEsab = strrev($basePath);
            if (strpos($htapEsab, '/') !== 0) {
                $basePath .= '/';
            }
        }
        return $basePath;
    }
}