<?php
/**
 * Copyright 2011 pixeltricks GmbH
 *
 * This file is part of SilvercartPaymentPaypal.
 *
 * SilvercartPaypalPayment is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * SilvercartPaymentPaypal is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with SilvercartPaymentPaypal.  If not, see <http://www.gnu.org/licenses/>.
 *
 * English (US) language pack
 *
 * @package SilvercartShipmentDhl
 * @subpackage Base
 * @ignore
 */

/**
 * The basic object where all configuration options for DHL shipment are stored
 * and all functionality is located.
 *
 * @package SilvercartShipmentDhl
 * @subpacke Base
 * @author Sascha Koehler <skoehler@pixeltricks.de>,
 *         Sebastian Diel <sdiel@pixeltricks.de>
 * @since 14.10.2013
 * @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
 * @copyright 2011 pixeltricks GmbH
 */
class SilvercartShipmentDhl extends DataObject {
    
    /**
     * Contains the path to the directory where the files should be saved.
     * 
     * @var string
     */
    protected $exportDirectory;
    
    /**
     * Contains the path to the directory from where files from Easylog should
     * be loaded.
     * 
     * @var string
     */
    protected $importDirectory;

    /**
     * Attributes
     * 
     * Legend for DHL-specific fields (starting with "POOL_"):
     *   O        Optional
     *   M        Mussfeld
     *   FE       Feste Eingabe in Editbox der Setupmaske möglich
     *   CMB      Feste Eingabe in Combobox der Setupmaske möglich
     *   FEPrEx   Feste Eingabe in „Produkt-Services“ Maske möglich. Es wird eine ähnliche Maske
     *            im Sendungsdialog angezeigt, um die Produkte und Services auszuwählen.
     *
     * @var array
     */
    public static $db = array(
        'activateCsvHeaders'           => 'Boolean',
        'lastExportDateTime'           => 'SS_Datetime',
        'csvSeparator'                 => 'VarChar(10)',
        'updateInterval'               => 'Int',
        'updateIntervalPeriod'         => "Enum('Minutes,Hours,Days,Weeks,Months,Years','Hours')",
        'exportDirectory'              => 'VarChar(255)',
        'importDirectory'              => 'VarChar(255)',
        'name'                         => 'VarChar(255)',
        'trackingUrl'                  => 'VarChar(255)',
        'POOL_REFNR'                   => 'VarChar(20)',    // O, FE
        'POOL_V_ABS_REFNR'             => 'VarChar(20)',    // M, CMB
        'POOL_ABS_BEMERKUNG'           => 'VarChar(20)',    // O, FE
        'POOL_V_MAND_REFNR'            => 'VarChar(20)',    // M, CMB
        'POOL_V_VERFAHREN'             => 'VarChar(2)',     // M, CMB
        'POOL_V_TEILNAHME'             => 'VarChar(2)',     // M, CMB
        'POOL_V_KSTSTELLE_KUERZEL'     => 'VarChar(10)',    // O, CMB
        'POOL_V_PRODUKT_CN'            => 'Int',            // M, FEPrEX
        'POOL_V_EXTRASLST'             => 'VarChar(255)',   // M, FEPrEX
        'POOL_V_NN_WAEHRUNG'           => 'VarChar(3)',     // M, CMB
        'POOL_WERT_WAEHRUNG_ID'        => 'VarChar(3)',     // M, CMB
        'POOL_EMPF_REFNR'              => 'VarChar(20)',    // O, FE
        'POOL_EMPF_NAME1'              => 'VarChar(40)',    // M, FE
        'POOL_EMPF_NAME2'              => 'VarChar(40)',    // O, FE
        'POOL_EMPF_NAME3'              => 'VarChar(40)',    // O, FE
        'POOL_EMPF_PLZ'                => 'VarChar(10)',    // M, FE
        'POOL_EMPF_ORT'                => 'VarChar(40)',    // M, FE
        'POOL_EMPF_ORTTEIL'            => 'VarChar(40)',    // C, FE
        'POOL_EMPF_STRASSE'            => 'VarChar(30)',    // M, FE
        'POOL_EMPF_HAUSNR'             => 'VarChar(10)',    // O, FE
        'POOL_EMPF_TEL'                => 'VarChar(30)',    // O, FE
        'POOL_EMPF_FAX'                => 'VarChar(30)',    // O, FE
        'POOL_EMPF_EMAIL'              => 'VarChar(50)',    // O, FE
        'POOL_EMPF_GEBDATUM'           => 'VarChar(10)',    // O, FE
        'POOL_EMPF_AUSWEISNR'          => 'VarChar(20)',    // O, FE
        'POOL_EMPF_AUSWEISART'         => 'VarChar(2)',     // O, CMB
        'POOL_EMPF_AUSWEISBEH'         => 'VarChar(30)',    // O, FE
        'POOL_EMPF_MINDESTALTER'       => 'VarChar(2)',     // O, FE
        'POOL_EMPF_MA_ORT'             => 'VarChar(35)',    // O, FE
        'POOL_EMPF_MA_STADTTEIL'       => 'VarChar(35)',    // O, FE
        'POOL_EMPF_MA_STRASSE'         => 'VarChar(35)',    // O, FE
        'POOL_EMPF_NACHNAME'           => 'VarChar(17)',    // O, FE
        'POOL_EMPF_VORNAME'            => 'VarChar(17)',    // O, FE
        'POOL_EMPF_VERTRAG_ID'         => 'VarChar(35)',    // O, FE
        'POOL_EMPF_IDP_CONF'           => 'VarChar(15)',    // O, FE
        'POOL_EMPF_APARTNER'           => 'VarChar(30)',    // O, FE
        'POOL_EMPF_BEMERKUNG'          => 'VarChar(30)',    // O, FE
        'POOL_EMPF_USTID'              => 'VarChar(20)',    // O, FE
        'POOL_EMPF_LANDCODE'           => 'VarChar(45)',    // M, CMB
        'POOL_EMPF_ZOLLBEZIRK'         => 'VarChar(9)',     // O, FE
        'POOL_GEWICHT'                 => 'VarChar(255)',   // O, FE
        'POOL_ANZAHL_SENDUNGEN'        => 'Int',            // O, FE
        'POOL_V_ZOLL_WARENART'         => 'Int',            // O, CMB
        'POOL_V_ZOLL_WARENLISTE'       => 'VarChar(255)',   // O, FE
        'POOL_ZOLL_MRNNUMBER'          => 'VarChar(18)',    // O, FE
        'POOL_V_VORAUSVERF_NAT'        => 'Int',            // O, CMB
        'POOL_V_VORAUSVERF_NAT_UNZUST' => 'Int',            // O, CMB
        'POOL_AVISE'                   => 'VarChar(21)',    // O, CMB
        'POOL_V_VORAUSVERF_INT'        => 'Int',            // O, CMB
        'POOL_V_VORAUSVERF_INT_TERMIN' => 'Int',            // O, CMB
        'POOL_V_VORAUSVERF_INT_TRANSP' => 'Int',            // O, CMB
        'POOL_EPACK_VORAUS'            => 'Int',            // O, CMB
        'POOL_IDENTEXPRESS'            => 'VarChar(255)',   // O, FE
        'POOL_ABWERK_ANZAHL'           => 'VarChar(3)',     // O, FE
        'POOL_ABWERK_NR'               => 'VarChar(10)',    // O, FE
        'POOL_ABWERK_DATE'             => 'VarChar(10)',    // O, FE
        'POOL_ABWERK_BBNNR'            => 'VarChar(10)',    // O, FE
        'POOL_SHIPMENT_ID'             => 'Int',            // O, FE
        'POOL_EXWORKS'                 => 'VarChar(10)',    // O, FE
        'POOL_CONTENTS'                => 'VarChar(10)',    // O, FE
        'POOL_VERWENDUNGSZWECK'        => 'VarChar(54)',    // O, FE
        'POOL_VORDATE'                 => 'Date',           // O, FE
        'POOL_SENDUNGSINHALTDHL'       => 'VarChar(40)',    // O, FE
        'POOL_RECHNUNGSARTDHL'         => 'Int',            // O, CMB
        'POOL_RECHNUNGSNUMMERDHL'      => 'VarChar(30)',    // O, FE
        'POOL_RECHNUNGSDATUMDHL'       => 'Date',           // O, FE
        'POOL_UNTERZEICHNERDHL'        => 'VarChar(30)',    // O, FE
        'POOL_ZOLLTARIFDHL'            => 'VarChar(30)',    // O, FE
        'POOL_RECHNUNGSBEMDHL'         => 'VarChar(255)',   // O, FE
        'POOL_EXPORTARTDHL'            => 'Int',            // O, CMB
        'POOL_EXPORTGRUNDDHL'          => 'VarChar(255)',   // O, FE
        'POOL_RECHNUNGSPOSITIONENDHL'  => 'VarChar(255)',   // O, FE
        'POOL_EXTRADATA'               => 'VarChar(255)'    // O, FE
    );
    
    /**
     * Has one relations
     *
     * @var type 
     */
    public static $has_one = array(
        'OrderStatusAfterExport'    => 'SilvercartOrderStatus',
        'OrderStatusAfterImport'    => 'SilvercartOrderStatus',
    );

    /**
     * Has-many relationships.
     *
     * @var array
     */
    public static $has_many = array(
        'SilvercartShipmentDhlFields' => 'SilvercartShipmentDhlField'
    );
    
    /**
     * Definitions for the "Verfahren" field.
     * 
     * @var array
     */
    public static $POOL_V_VERFAHREN = array(
        '1'     => 'NATIONAL',
        '53'    => 'INTERNATIONAL',
        '54'    => 'DHL EUROPAKET',
        '69'    => 'DHL EUROPLUS',
        '72'    => 'EXPRESS',
        '99'    => 'INTERNATIONAL EXPRESS'
    );
    
    /**
     * Definitions for the "Produkt_CN" field.
     * 
     * @var array
     */
    public static $POOL_V_PRODUKT_CN = array(
        
        // NATIONAL
        '101' => array(
            'title'     => 'EUROPACK NATIONAL / DHL PAKET (VPP)',
            'service'   => 'NATIONAL_VPP'
        ),
        '108' => array(
            'title'     => 'HAUS HAUS BEHÄLTER',
            'service'   => 'NATIONAL'
        ),
        '118' => array(
            'title'     => 'AB WERK',
            'service'   => 'NATIONAL'
        ),
        '121' => array(
            'title'     => 'POSTBOX POOL M3',
            'service'   => 'NATIONAL'
        ),
        '122' => array(
            'title'     => 'POSTBOX POOL M4',
            'service'   => 'NATIONAL'
        ),
        '123' => array(
            'title'     => 'POSTBOX POOL M6',
            'service'   => 'NATIONAL'
        ),
        '124' => array(
            'title'     => 'POSTBOX TAUSCH T3',
            'service'   => 'NATIONAL'
        ),
        '125' => array(
            'title'     => 'POSTBOX TAUSCH T4',
            'service'   => 'NATIONAL'
        ),
        '126' => array(
            'title'     => 'POSTBOX TAUSCH T6',
            'service'   => 'NATIONAL'
        ),
        '127' => array(
            'title'     => 'EUROPACK NATIONAL PLUS',
            'service'   => 'NATIONAL'
        ),
        '128' => array(
            'title'     => 'POSTBOX PLUS M3',
            'service'   => 'NATIONAL'
        ),
        '129' => array(
            'title'     => 'POSTBOX PLUS M4',
            'service'   => 'NATIONAL'
        ),
        '130' => array(
            'title'     => 'POSTBOX PLUS M6',
            'service'   => 'NATIONAL'
        ),
        
        // REGIONALPAKET AT
        '666' => array(
            'title'     => 'REGIONALPAKET AT',
            'service'   => 'REGIONALPAKET_AT'
        ),
        
        // INTERNATIONAL
        '5301' => array(
            'title'     => 'PREMIUM',
            'service'   => 'INTERNATIONAL'
        ),
        '5302' => array(
            'title'     => 'BUSINESSPAKET INTERNATIONAL / WELTPAKET (VPP)',
            'service'   => 'INTERNATIONAL'
        ),
        '5303' => array(
            'title'     => 'SEEPAKET',
            'service'   => 'INTERNATIONAL'
        ),
        
        // DHL EUROPAKET
        '5401' => array(
            'title'     => 'DHL EUROPAKET',
            'service'   => 'NATIONAL_VPP'
        ),
        
        // DHL EUROPLUS
        '6901' => array(
            'title'     => 'DHL EUROPLUS',
            'service'   => 'NATIONAL_VPP'
        ),
        
        // EXPRESS
        '7201' => array(
            'title'     => 'EXPRESSBRIEF',
            'service'   => 'NATIONAL_VPP'
        ),
        '7202' => array(
            'title'     => 'EXPRESSPAKET',
            'service'   => 'NATIONAL_VPP'
        ),
        '7203' => array(
            'title'     => 'EXPRESSPAKET MEHRKOLLI',
            'service'   => 'NATIONAL_VPP'
        ),
        '7204' => array(
            'title'     => 'EXPRESSPAKET FRACHT',
            'service'   => 'NATIONAL_VPP'
        ),
        '7205' => array(
            'title'     => 'OFFICEPACK',
            'service'   => 'NATIONAL_VPP'
        ),
        '7206' => array(
            'title'     => 'OFFICEPACK-PLUS',
            'service'   => 'NATIONAL_VPP'
        ),
        '7225' => array(
            'title'     => 'VALUEPACK',
            'service'   => 'NATIONAL_VPP'
        )
    );
    
    /**
     * DHL services definitions.
     * 
     * @var array
     */
    public static $SERVICES= array(
        
        // NATIONAL
        'NATIONAL' => array(
            '107' => 'Lang',
            '109' => 'Mehrpaket Zustellung Teilauslieferung möglich',
            '112' => 'Mehrpaket Zustellung Teilauslieferung nicht möglich',
            '110' => 'Rückschein',
            '111' => 'Unfrei',
            '113' => 'Sperrgut',
            '114' => 'Nachnahme',
            '119' => 'Transportversicherung - bis 2.500 EUR',
            '120' => 'Transportversicherung - bis 25.000 EUR',
            '132' => 'Vorausverfügung',
            '133' => 'Rolle o. Beförderungshilfe',
            '134' => 'Beleglose Nachnahme',
            '144' => 'EPN L',
            '145' => 'EPN XL',
            '146' => 'EPN XXL',
            '150' => 'Sendungsavise',
            '505' => 'Eigenhändig',
            '506' => 'Identitätsprüfung',
            '507' => 'Identitäts- und Altersprüfung',
            '508' => 'Identitätsprüfung PREMIUM'
        ),
        
        // NATIONAL VPP
        'NATIONAL_VPP' => array(
            '109' => 'Mehrpaket Zustellung Teilauslieferung möglich',
            '112' => 'Mehrpaket Zustellung Teilauslieferung nicht möglich',
            '110' => 'Rückschein',
            '111' => 'Unfrei',
            '113' => 'Sperrgut',
            '114' => 'Nachnahme',
            '119' => 'Transportversicherung - bis 2.500 EUR',
            '120' => 'Transportversicherung - bis 25.000 EUR',
            '134' => 'Beleglose Nachnahme',
            '150' => 'Sendungsavise',
            '505' => 'Eigenhändig',
            '506' => 'Identitätsprüfung',
            '507' => 'Identitäts- und Altersprüfung',
            '508' => 'Identitätsprüfung PREMIUM'
        ),
        
        // REGIONALPAKET AT
        'REGIONALPAKET_AT' => array(),
        
        // INTERNATIONAL
        'INTERNATIONAL' => array(
            '5306' => 'Sperrgut',
            '5309' => 'Rückschein',
            '5311' => 'Nachnahme',
            '5313' => 'Vorausverfügung',
            '5314' => 'Rolle o. Beförderungshilfe',
            '5398' => 'Transportversicherung - bis 2.500 EUR',
            '5399' => 'Transportversicherung - bis 25.000 EUR'
        ),
        
        // DHL EUROPAKET
        'DHL_EUROPAKET' => array(
            '5410' => 'Frankatur DDU',
            '5411' => 'Frankatur DDP',
            '5412' => 'Frankatur DDP o. Steuern',
            '5413' => 'Frankatur DDP o. Steuern und Zölle',
            '5414' => 'Frankatur CPT',
            '5498' => 'Transportversicherung - bis 2.500 EUR',
            '5499' => 'Transportversicherung - bis 25.000 EUR',
            '5460' => 'Gefahrgut in begrenzten Mengen'
        ),
        
        // DHL EUROPLUS
        'DHL_EUROPLUS' => array(
            '6910 ' => 'Sicher Transportversicherung',
            '6911 ' => 'Inkasso Nachnahme',
            '6912 ' => 'Empfänger zahlt',
            '6915 ' => 'Frankatur DDU',
            '6916 ' => 'Frankatur DDP',
            '6917 ' => 'Frankatur DDP o. Steuern',
            '6918 ' => 'Frankatur DDP o. Steuern und Zölle',
            '6919 ' => 'Frankatur Ex Works (Unfrei)',
            '6921 ' => 'Frankatur CPT'
        ),
        
        // EXPRESS
        'EXPRESS' => array(
            '7207' => 'Zeit der Zustellung - Sonderfrüh',
            '7208' => 'Zeit der Zustellung - vor 9 Uhr',
            '7209' => 'Zeit der Zustellung - vor 10 Uhr',
            '7210' => 'Zeit der Zustellung - vor 12 Uhr',
            '7211' => 'Zeit der Zustellung – Samstag',
            '7212' => 'Zeit der Zustellung - Sonn-/Feiertags',
            '7213' => 'Eigenhändig',
            '7214' => 'Rückschein',
            '7215' => 'Zeit der Abholung - Samstag',
            '7216' => 'Zeit der Abholung – Spät',
            '7217' => 'Transportversicherung - bis 2.500 EUR',
            '7218' => 'Transportversicherung - bis 25.000 EUR',
            '7219' => 'Zeitpunktzustellung',
            '7220' => 'Zeit der Zustellung - 12 bis 17 Uhr',
            '7221' => 'Zeit der Zustellung - 17 bis 22 Uhr',
            '7222' => 'Kein BK',
            '7223' => 'EXPRESS IDENT SERVICE',
            '7272' => 'Zustell Avise (SMS)',
            '7224' => 'Nachnahme',
            '7226' => 'unfrei gegen Barzahlung',
            '7227' => 'unfrei auf Rechnung',
            '7228' => 'Gefahrgut gem. ADR LQ',
            '7229' => 'Gefahrgut über ADR LQ'
        ),
        
        // RETOURE / Retourenpaket (VPP)
        'RETOURE' => array(
            '703' => 'Retoure / Retourenpaket (VPP)'
        ),
        
        // INTERNATIONAL EXPRESS
        'INTERNATIONAL_EXPRESS' => array(
            '9911' => 'Zeit der Zustellung - vor 9 Uhr',
            '9912' => 'Zeit der Zustellung - vor 12 Uhr',
            '9913' => 'Zeit der Zustellung – Samstag',
            '9921' => 'Absender als Rechnungsempfänger',
            '9922' => 'Empfänger als Rechungsempfänger',
            '9923' => 'Third Party Rechnungsempfänger',
            '9924' => 'Empfänger zahlt (unfrei)',
            '9931' => 'Transportversicherung',
            '9941' => 'Warenwert',
            '9960' => 'Gefahrgut gem. IATA-DGR',
            '9970' => 'Handelsbedingung DDP',
            '9971' => 'Handelsbedingung DDU',
            '9972' => 'Handelsbedingung DVU'
        )
    );
    
    /**
     * Sets the singular name for this object.
     *
     * @return string
     *
     * @author Sascha Koehler <skoehler@pixeltricks.de>, Sebastian Diel <sdiel@pixeltricks.de>
     * @since 10.07.2012
     */
    public function singular_name() {
        return SilvercartTools::singular_name_for($this);
    }
    
    /**
     * Sets the plural name for this object.
     *
     * @return string
     *
     * @author Sascha Koehler <skoehler@pixeltricks.de>, Sebastian Diel <sdiel@pixeltricks.de>
     * @since 10.07.2012
     */
    public function plural_name() {
        return SilvercartTools::plural_name_for($this);
    }
    
    /**
     * The configuration object shouldn't be deletable.
     *
     * @return boolean false
     *
     * @author Sascha Koehler <skoehler@pixeltricks.de>, Sebastian Diel <sdiel@pixeltricks.de>
     * @since 10.07.2012
     */
    public function canDelete() {
        return false;
    }
    
    /**
     * We set some preferences here.
     * 
     * @param array|null $record      This will be null for a new database record.  Alternatively, you can pass an array of field values.
     *                                Normally this contructor is only used by the internal systems that get objects from the database.
     * @param boolean    $isSingleton This this to true if this is a singleton() object, a stub for calling methods.
     *                                Singletons don't have their defaults set.
     * 
     * @return void
     * 
     * @author Sascha Koehler <skoehler@pixeltricks.de>, Sebastian Diel <sdiel@pixeltricks.de>
     * @since 10.07.2012
     */
    public function __construct($record = null, $isSingleton = false) {
        parent::__construct($record, $isSingleton);
        
        $this->exportDirectory  = Director::baseFolder().'/silvercart_shipment_dhl/export_files/';
        $this->importDirectory  = Director::baseFolder().'/silvercart_shipment_dhl/import_files/';
    }
    
    /**
     * Set the field labels
     *
     * @param boolean $includerelations Indicate wether to include relations
     * 
     * @return array
     *
     * @author Sascha Koehler <skoehler@pixeltricks.de>, Sebastian Diel <sdiel@pixeltricks.de>
     * @since 21.09.2012
     */
    public function fieldLabels($includerelations = true) {
        $fieldLabels = array_merge(
                parent::fieldLabels($includerelations),
                array(
                    'activateCsvHeaders'        => _t('SilvercartShipmentDhl.ACTIVATE_CSV_HEADERS'),
                    'name'                      => _t('SilvercartShipmentDhl.NAME'),
                    'csvSeparator'              => _t('SilvercartShipmentDhl.CSV_SEPARATOR'),
                    'updateInterval'            => _t('SilvercartShipmentDhl.UPDATE_INTERVAL'),
                    'updateIntervalPeriod'      => _t('SilvercartShipmentDhl.UPDATE_INTERVAL_PERIOD'),
                    'exportDirectory'           => _t('SilvercartShipmentDhl.EXPORT_DIRECTORY'),
                    'importDirectory'           => _t('SilvercartShipmentDhl.IMPORT_DIRECTORY'),
                    'trackingUrl'               => _t('SilvercartShipmentDhl.TRACKING_URL'),
                    'OrderStatusAfterExport'    => _t('SilvercartShipmentDhl.ORDERSTATUS_AFTER_EXPORT'),
                    'OrderStatusAfterImport'    => _t('SilvercartShipmentDhl.ORDERSTATUS_AFTER_IMPORT'),
                    'DoNotChangeOrderStatus'    => _t('SilvercartShipmentDhl.DO_NOT_CHANGE_ORDERSTATUS'),
                )
        );
        
        $this->extend('updateFieldLabels', $fieldLabels);
        return $fieldLabels;
    }
    
    /**
     * Summaryfields for display in tables.
     *
     * @return array
     *
     * @author Sascha Koehler <skoehler@pixeltricks.de>
     * @since 04.08.2011
     */
    public function summaryFields() {
        $summaryFields = array(
            'name' => _t('SilvercartShipmentDhl.NAME')
        );
        
        $this->extend('updateSummaryFields', $summaryFields);
        return $summaryFields;
    }

    /**
     * Sets the GUI for the storeadmin..
     *
     * @param array $params See {@link scaffoldFormFields()}
     *
     * @return FieldSet
     */
    public function getCMSFields($params = null) {
        $fields     = parent::getCMSFields($params);
        
        $tabset     = new TabSet('Sections');
        $dbFields   = DataObject::database_fields('SilvercartShipmentDhl');
        $lastExport = $this->lastExportDateTime;
        
        if (!$lastExport) {
            $lastExport = '---';
        }
        
        // --------------------------------------------------------------------
        // Basic settings
        // --------------------------------------------------------------------
        $tabBasic = new Tab('Basic', _t('SilvercartShipmentDhl.TAB_BASIC_SETTINGS', 'Basic settings'));
        $tabset->push($tabBasic);
        
        $tabBasic->setChildren(
            new FieldSet(
                $fields->dataFieldByName('name'),
                $fields->dataFieldByName('csvSeparator'),
                $fields->dataFieldByName('exportDirectory'),
                $fields->dataFieldByName('importDirectory'),
                $fields->dataFieldByName('updateInterval'),
                $fields->dataFieldByName('updateIntervalPeriod'),
                $fields->dataFieldByName('trackingUrl'),
                $fields->dataFieldByName('OrderStatusAfterExportID'),
                $fields->dataFieldByName('OrderStatusAfterImportID'),
                new LiteralField('lastExportDateTime', '<p>'._t('SilvercartShipmentDhl.FIELD_LAST_EXPORT_DATE_TIME').': '.$lastExport.'</p>')
            )
        );
        
        $fields->dataFieldByName('OrderStatusAfterExportID')->setEmptyString($this->fieldLabel('DoNotChangeOrderStatus'));
        $fields->dataFieldByName('OrderStatusAfterImportID')->setEmptyString($this->fieldLabel('DoNotChangeOrderStatus'));
        
        // --------------------------------------------------------------------
        // Export field definitions
        // --------------------------------------------------------------------
        $tabExportFieldDefinitions = new Tab('ExportFieldDefinitions', _t('SilvercartShipmentDhl.TAB_EXPORT_FIELD_DEFINITIONS', 'Export field definitions'));
        $tabset->push($tabExportFieldDefinitions);
        
        $availableFields    = array();
        
        foreach ($dbFields as $fieldName => $fieldType) {
            $availableFields[$fieldName] = $fieldName;
        }
        
        $multiSelect2SideField = new SilvercartMultiSelectAndOrderField(
            $this,
            'SilvercartShipmentDhlFields',
            'availableExportFields',
            _t('SilvercartProductExport.FIELD_AVAILABLE_EXPORT_FIELDS'),
            $availableFields,
            '',
            10,
            true
        );
        
        $tabExportFieldDefinitions->setChildren(
            new FieldSet(
                new HeaderField(
                    'attributeExportFieldsLabel',
                    _t('SilvercartProductExport.ATTRIBUTE_EXPORT_FIELDS_LABEL'),
                    2
                ),
                $multiSelect2SideField
            )
        );
        
        // --------------------------------------------------------------------
        // Header configuration
        // --------------------------------------------------------------------
        $tabHeaderConfiguration = new Tab('HeaderConfiguration', _t('SilvercartShipmentDhl.TAB_HEADER_CONFIGURATION', 'Header configuration'));
        $tabset->push($tabHeaderConfiguration);
        
        $tabHeaderFieldSet = new FieldSet();
        
        $tabHeaderFieldSet->push(
            $fields->dataFieldByName('activateCsvHeaders')
        );
        
        // Create exporterField list
        $exporterFields = $this->SilvercartShipmentDhlFields();
        $exporterFields->sort('sortOrder', 'ASC');
        
        foreach ($exporterFields as $exporterField) {
            if (empty($exporterField->headerTitle)) {
                $headerTitle = $exporterField->name;
            } else {
                $headerTitle = $exporterField->headerTitle;
            }
            
            $mappingField = new TextField('SilvercartShipmentDhlFields_'.$exporterField->name, $exporterField->name, $headerTitle);
            $tabHeaderFieldSet->push($mappingField);
        }
        
        $tabHeaderConfiguration->setChildren(
            $tabHeaderFieldSet
        );
        
        // --------------------------------------------------------------------
        // Field default value configuration
        // --------------------------------------------------------------------
        $tabDefaultValueConfiguration = new Tab('DefaultValueConfiguration', _t('SilvercartShipmentDhl.TAB_DEFAULT_VALUE_CONFIGURATION', 'Default value configuration'));
        $tabset->push($tabDefaultValueConfiguration);
        
        $tabDefaultValueFieldSet = new FieldSet();
        
        // Create field list
        $exporterFields = $this->SilvercartShipmentDhlFields();
        $exporterFields->sort('sortOrder', 'ASC');
        
        foreach ($exporterFields as $exporterField) {
            $defaultValue = $exporterField->defaultValue;
            
            $mappingField = new TextField('SilvercartShipmentDhlFields_defaultValue_'.$exporterField->name, $exporterField->name, $defaultValue);
            $tabDefaultValueFieldSet->push($mappingField);
        }
        
        $tabDefaultValueConfiguration->setChildren(
            $tabDefaultValueFieldSet
        );
        
        $newFields = new FieldSet($tabset);
        $this->extend('updateCMSFields', $newFields);
        return $newFields;
    }
    
    /**
     * Returns the export directory
     * 
     * @return string
     */
    public static function getExportDirectory() {
        $shipmentDhl = DataObject::get_one('SilvercartShipmentDhl');

        if ($shipmentDhl &&
            !empty($shipmentDhl->exportDirectory) &&
            is_dir($shipmentDhl->exportDirectory)) {

            $exportDirectory = $shipmentDhl->exportDirectory;
        } else {
            $exportDirectory = Director::baseFolder() . '/silvercart_shipment_dhl/export_files/';
        }
        
        if (substr($exportDirectory, -1) != '/') {
            $exportDirectory .= '/';
        }
        return $exportDirectory;
    }
    
}

/**
 * The basic object where all configuration options for DHL shipment are stored
 * and all functionality is located.
 *
 * @package SilvercartShipmentDhl
 * @subpacke Base
 * @author Sascha Koehler <skoehler@pixeltricks.de>
 * @since 04.08.2011
 * @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
 * @copyright 2011 pixeltricks GmbH
 */
class SilvercartShipmentDhl_CollectionController extends ModelAdmin_CollectionController {
    
    /**
	 * We don't want to show the import form here.
     * 
     * @author Sascha Koehler <skoehler@pixeltricks.de>
     * @since 04.08.2011
	 */
    public $showImportForm = false;
    
    /**
     * We don't want to show a create form here.
     *
     * @return boolean false
     *
     * @author Sascha Koehler <skoehler@pixeltricks.de>
     * @since 03.08.2011
     */
    public function CreateForm() {
        return false;
    }
    
}

/**
 * The basic object where all configuration options for DHL shipment are stored
 * and all functionality is located.
 *
 * @package SilvercartShipmentDhl
 * @subpacke Base
 * @author Sascha Koehler <skoehler@pixeltricks.de>
 * @since 04.08.2011
 * @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
 * @copyright 2011 pixeltricks GmbH
 */
class SilvercartShipmentDhl_RecordController extends ModelAdmin_RecordController {
    
    
    
}