<?php
/**
 * Copyright 2011 pixeltricks GmbH
 *
 * This file is part of SilverCart.
 *
 * SilverCart is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * SilverCart is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with SilverCart.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package SilvercartShipmentDhl
 * @subpackage Config
 */

/**
 * Creates a SilvercartShipmentDhl configuration object if none exists yet.
 *
 * @package SilvercartShipmentDhl
 * @subpackage Config
 * @author Sascha Koehler <skoehler@pixeltricks.de>
 * @copyright 2011 pixeltricks GmbH
 * @since 04.08.2011
 * @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
 */
class SilvercartShipmentDhlRequireDefaultRecords extends DataObjectDecorator {
    
    /**
     * Creates a SilvercartShipmentDhl configuration object if none exists yet
     * and a set of fields.
     *
     * @param SS_HTTPRequest $request The request object
     * 
     * @return void
     *
     * @author Sascha Koehler <skoehler@pixeltricks.de>
     * @since 04.08.2011
     */
    public function updateDefaultRecords($request) {
        $configurationObj = DataObject::get_one(
            'SilvercartShipmentDhl'
        );
        
        if (!$configurationObj) {
            
            // Create the configuration object
            $configurationObj = new SilvercartShipmentDhl();
            $configurationObj->setField('activateCsvHeaders',   true);
            $configurationObj->setField('csvSeparator',         ';');
            $configurationObj->setField('updateInterval',       '8');
            $configurationObj->setField('updateIntervalPeriod', 'Hours');
            $configurationObj->setField('trackingUrl',          'http://nolp.dhl.de/nextt-online-public/set_identcodes.do?lang=de&rfn=&extendedSearch=true&idc=');
            $configurationObj->setField('name',                 _t('SilvercartShipmentDhl.STANDARD_NAME'));
            
            $configurationObj->write();
            
            // Create attributed fields for the configuration object
            $standardFields = array(
                'POOL_REFNR',
                'POOL_EMPF_REFNR',
                'POOL_EMPF_NAME1',
                'POOL_EMPF_VORNAME',
                'POOL_EMPF_NACHNAME',
                'POOL_EMPF_PLZ',
                'POOL_EMPF_ORT',
                'POOL_EMPF_STRASSE',
                'POOL_EMPF_HAUSNR',
                'POOL_EMPF_LANDCODE'
            );
            
            $fieldIdx = 1;
            
            foreach ($standardFields as $field) {
                $fieldObj = new SilvercartShipmentDhlField();
                $fieldObj->setField('SilvercartShipmentDhlID',  $configurationObj->ID);
                $fieldObj->setField('name',                     $field);
                $fieldObj->setField('headerTitle',              $field);
                $fieldObj->setField('sortOrder',                $fieldIdx);
                $fieldObj->setField('isCallbackField',          0);
                $fieldObj->setField('defaultValue',             '');
                $fieldObj->write();
                
                $fieldIdx++;
            }
        }
    }
}